#ifndef EXTENDEDLOG_TEXTLOGWRITER_HPP
#define EXTENDEDLOG_TEXTLOGWRITER_HPP

#include "EntryType.hpp"
#include "ExtendedLog_global.h"
#include "LogWriter.hpp"

#include <QFile>
#include <QString>
#include <QTextStream>

namespace ExtendedLog
{
	/**
	 * @brief A text-based log-writer
	 */
	class EXTENDEDLOG_EXPORT TextLogWriter : public LogWriter
	{
		public:
			/**
			 * @brief Create a new plaintext-based logwriter
			 * @param filename the file to use as log-file
			 */
			TextLogWriter(QString filename);

			/**
			 * @brief Write an LogEntry to the log file
			 * @param type The type of the entry
			 * @param message The message of the entry
			 */
			void writeEntry(EntryType type, QString message);

			/**
			 * @brief Close this log-writer
			 */
			void close();
	
		private:
			/**
			 * @brief The file to use as log-file
			 */
			QFile file;

			/**
			 * @brief The text-writer to use
			 */
			QTextStream writer;
	
	};
} // namespace ExtendedLog

#endif // EXTENDEDLOG_TEXTLOGWRITER_HPP
