#ifndef XMLLOGWRITER_HPP
#define XMLLOGWRITER_HPP

#include "ExtendedLog_global.h"
#include "LogWriter.hpp"

#include <QFile>
#include <QString>
#include <QXmlStreamWriter>

namespace ExtendedLog
{
	/**
	 * @brief The XmlLogWriter class
	 *
	 * This class provides an log-writer based on XML-files.
	 */
	class EXTENDEDLOG_EXPORT XmlLogWriter : public LogWriter
	{
		public:
			/**
			 * @brief Create a new xml-based logwriter
			 * @param filename The file to use as log-file
			 */
			XmlLogWriter(QString filename);

			/**
			 * @brief Write an LogEntry to the log file
			 * @param type The type of the entry
			 * @param message The message of the entry
			 */
			void writeEntry(EntryType type, QString message);

			/**
			 * @brief Close this log-writer
			 */
			void close();
	
		private:
			/**
			 * @brief The file to use for writing
			 */
			QFile inputFile;

			/**
			 * @brief The XML-writer
			 */
			QXmlStreamWriter xmlWriter;
	};
} // namespace ExtendedLog
#endif // XMLLOGWRITER_HPP
